@@ -10,7 +10,6 @@
 #include "xf86Resources.h"
 
 /* All drivers need this */
-#include "xf86_ansic.h"
 
 #include "compiler.h"
 
@@ -151,6 +150,8 @@ GenerateModeList(ScrnInfoPtr pScrn, char* str,
             case 0:
             case '-':
             case ' ':
+	    case ',':
+	    case ';':
                 if((strmode != str)) {/*we got a mode */
                     /* read new entry */
                     strncpy(modename,strmode,str - strmode);
@@ -174,11 +175,11 @@ GenerateModeList(ScrnInfoPtr pScrn, char* str,
                                 "Mode: \"%s\" is not a supported mode for monitor 1\n",modename);
                             /* find if a monitor2 mode follows */
                             gotdash = FALSE;
-                            while(*tmps == ' ') tmps++;
-                            if(*tmps == '-') { /* skip the next mode */
+                            while(*tmps == ' ' || *tmps == ';') tmps++;
+                            if(*tmps == '-' || *tmps == ',') { /* skip the next mode */
                                 tmps++;
-                                while((*tmps == ' ') && (*tmps != 0)) tmps++; /*skip spaces */
-                                while((*tmps != ' ') && (*tmps != '-') && (*tmps != 0)) tmps++; /*skip modename */
+                                while(*tmps == ' ' || *tmps == ';') tmps++; /*skip spaces */
+                                while(*tmps && *tmps != ' ' && *tmps != ';' && *tmps != '-' && *tmps != ',') tmps++; /*skip modename */
                                 /* for error message */
                                 strncpy(modename,strmode,tmps - strmode);
                                 modename[tmps - strmode] = 0;
@@ -192,7 +193,7 @@ GenerateModeList(ScrnInfoPtr pScrn, char* str,
                     gotdash = FALSE;
                 }
                 strmode = str+1; /* number starts on next char */
-                gotdash |= (*str == '-');
+                gotdash |= (*str == '-' || *str == ',');
                 
                 if(*str != 0) break; /* if end of string, we wont get a chance to catch a char and run the
                                         default case. do it now */
@@ -360,6 +361,8 @@ MGAPreInitMergedFB(ScrnInfoPtr pScrn1, int flags)
     case PCI_CHIP_MGAG100_PCI:
     case PCI_CHIP_MGAG200:
     case PCI_CHIP_MGAG200_PCI:
+    case PCI_CHIP_MGAG200_SE_A_PCI:
+    case PCI_CHIP_MGAG200_SE_B_PCI:
     case PCI_CHIP_MGAG400:
     case PCI_CHIP_MGAG550:
 	MGAGSetupFuncs(pScrn);
@@ -509,6 +512,8 @@ MGAPreInitMergedFB(ScrnInfoPtr pScrn1, int flags)
 	   break;
 	case PCI_CHIP_MGAG200:
 	case PCI_CHIP_MGAG200_PCI:
+	case PCI_CHIP_MGAG200_SE_A_PCI:
+	case PCI_CHIP_MGAG200_SE_B_PCI:
 	case PCI_CHIP_MGAG400:
 	case PCI_CHIP_MGAG550:
 	   maxPitch = 4096;
@@ -942,23 +947,28 @@ MGASaveScreenMerged(ScreenPtr pScreen, int mode)
     
     if (on) {
 /*        SetTimdeSinceLastInputEvent();*/
-       
+
         /* power on Dac1 */
-        reg = inMGAdac(0x1E);
-	outMGAdac(0x1E, reg | 1);
+        reg = inMGAdac(MGA1064_MISC_CTL);
+        reg |= MGA1064_MISC_CTL_DAC_EN;
+        outMGAdac(MGA1064_MISC_CTL, reg);
+
         /* power on Dac2 */
-        reg = inMGAdac(0xA0);
-	outMGAdac(0xA0, reg | 1);
-        
+        reg = inMGAdac(MGA1064_PWR_CTL);
+        reg |= 1;
+        outMGAdac(MGA1064_PWR_CTL, reg);
     } else {
         /* power off Dac1 */
-        reg = inMGAdac(0x1E);
-	outMGAdac(0x1E, reg & ~1);
-        /* power off Dac2 */
-        reg = inMGAdac(0xA0);
-	outMGAdac(0xA0, reg & ~1);
+        reg = inMGAdac(MGA1064_MISC_CTL);
+        reg &= ~MGA1064_MISC_CTL_DAC_EN;
+        outMGAdac(MGA1064_MISC_CTL, reg);
 
+        /* power off Dac2 */
+        reg = inMGAdac(MGA1064_PWR_CTL);
+        reg &= ~1;
+        outMGAdac(MGA1064_PWR_CTL, reg);
     }
+
     return TRUE;
 }
 
